@@ -2,13 +2,37 @@
 # this repository contains the full copyright notices and license terms.
 import unittest
 
-from sql import Table, Window, AliasManager, Flavor, Literal
-from sql.aggregate import Avg, Count
+from sql import AliasManager, Flavor, Literal, Table, Window
+from sql.aggregate import Aggregate, Avg, Count
 
 
 class TestAggregate(unittest.TestCase):
     table = Table('t')
 
+    def test_invalid_expression(self):
+        with self.assertRaises(ValueError):
+            Aggregate('foo')
+
+    def test_invalid_distinct(self):
+        with self.assertRaises(ValueError):
+            Aggregate(self.table.c, distinct='foo')
+
+    def test_invalid_order(self):
+        with self.assertRaises(ValueError):
+            Aggregate(self.table.c, order_by=['foo'])
+
+    def test_invalid_within(self):
+        with self.assertRaises(ValueError):
+            Aggregate(self.table.c, within=['foo'])
+
+    def test_invalid_filter(self):
+        with self.assertRaises(ValueError):
+            Aggregate(self.table.c, filter_='foo')
+
+    def test_invalid_window(self):
+        with self.assertRaises(ValueError):
+            Aggregate(self.table.c, window='foo')
+
     def test_avg(self):
         avg = Avg(self.table.c)
         self.assertEqual(str(avg), 'AVG("c")')
@@ -16,6 +40,11 @@ class TestAggregate(unittest.TestCase):
         avg = Avg(self.table.a + self.table.b)
         self.assertEqual(str(avg), 'AVG(("a" + "b"))')
 
+    def test_count_without_expression(self):
+        count = Count()
+        self.assertEqual(str(count), 'COUNT(*)')
+        self.assertEqual(count.params, ())
+
     def test_order_by_one_column(self):
         avg = Avg(self.table.a, order_by=self.table.b)
         self.assertEqual(str(avg), 'AVG("a" ORDER BY "b")')
